// EAPI_Test.cpp : Defines the entry point for the console application.
//

//#####################################
//########## Include files ############

#ifdef CODE_for_WINDOWS
#include <exception>
#include <ctime>
#include <string>
#include <cstring>
#include <fstream>
#include <fcntl.h>
#include <errno.h>
#include <stdlib.h>
#include <stdio.h>
#endif

#ifdef CODE_for_LINUX
#include <unistd.h>
#else
#include <iostream>
#endif

#include "EApi.h"
#include "EApi_Seco.h"

//#####################################
//############## Defines ##############

#define PARAMETER_ERROR         0

#define GET_SPEC_VERSION		        1
#define GET_BOARD_BOOT_COUNTER          2
#define GET_BOARD_RUNNING_TIME_METER    3
#define GET_BOARD_PNPID                 4
#define GET_BOARD_PLATFORM_REV	        5
#define GET_BOARD_DRIVER_VERSION        6
#define GET_BOARD_LIB_VERSION           7
#define GET_HWMON_CPU_TEMP              8
#define GET_HWMON_CHIPSET_TEMP          9
#define GET_HWMON_SYSTEM_TEMP           10
#define GET_HWMON_VOLTAGE_VCORE         11
#define GET_HWMON_VOLTAGE_2V5           12
#define GET_HWMON_VOLTAGE_3V3           13
#define GET_HWMON_VOLTAGE_VBAT          14
#define GET_HWMON_VOLTAGE_5V            15
#define GET_HWMON_VOLTAGE_5VSB          16
#define GET_HWMON_VOLTAGE_12V           17
#define GET_HWMON_FAN_CPU               18
#define GET_HWMON_FAN_SYSTEM            19
// -----------------------------------
#define GET_HWMON_RAM_TEMP		        100
#define GET_SWITCH_STATUS		        101
// -----------------------------------
#define GET_BOARD_MANUFACTURER          20
#define GET_BOARD_NAME			        21
#define GET_BOARD_REVISION		        22
#define GET_BOARD_SERIAL		        23
#define GET_BOARD_BIOS_REVISION         24
#define GET_BOARD_HW_REVISION           25
#define GET_BOARD_PLATFORM_TYPE         26
// -----------------------------------
#define GET_LCD_BCKL_ENA                30
#define SET_LCD_BCKL_ENA                31
#define GET_LCD_BACKLIGHT		        32
#define SET_LCD_BACKLIGHT		        33
// -----------------------------------
#define NVS_CAP                         40
#define NVS_READ                        41
#define NVS_WRITE                       42
// -----------------------------------
#define WDOG_CAP				        50
#define WDOG_START                      51
#define WDOG_TRIGGER			        52
#define WDOG_STOP                       53
#define WDOG_START_CUSTOM               102
// -----------------------------------
#define I2C_CAP					        60
#define I2C_WRITE_READ_RAW              61
#define I2C_READ                        62
#define I2C_WRITE                       63
#define I2C_PROBE				        64
// -----------------------------------
#define GPIO_GET_DIRECTION_CAP	        70
#define GPIO_GET_DIRECTION		        71
#define GPIO_SET_DIRECTION		        72
#define GPIO_GET_LEVEL			        73
#define GPIO_SET_LEVEL			        74
#define GPIO_GET_SERIAL_CFG             103
#define GPIO_SET_SERIAL_CFG             104
// -----------------------------------
#define FAN_ENABLE                      110
#define FAN_DISABLE                     111
#define FAN_GET_CYCLE                   112
#define FAN_SET_CYCLE                   113
#define FAN_GET_DUTY                    114
#define FAN_SET_DUTY                    115
// -----------------------------------
#define SET_CARRIER                     120
// -----------------------------------
#define GET_RESET_CAUSE                 140
#define CLEAR_RESET_CAUSE               141
// -----------------------------------
#define SPI_CAP					        150
#define SPI_WRITE_READ_RAW              151
// -----------------------------------
// -----------------------------------
#define POWER_RAIL_CYCLE                160
// -----------------------------------
#define HELP				            254
// -----------------------------------
#define NONE				            255
// -----------------------------------

 #define _EAPI_STATUS_NOT_INITIALIZED			10
 #define _EAPI_STATUS_INITIALIZED				11
 #define _EAPI_STATUS_ALLOC_ERROR				12
 #define _EAPI_STATUS_DRIVER_TIMEOUT			13
 #define _EAPI_STATUS_INVALID_PARAMETER			14
 #define _EAPI_STATUS_INVALID_BLOCK_ALIGNMENT	15
 #define _EAPI_STATUS_INVALID_BLOCK_LENGTH		16
 #define _EAPI_STATUS_INVALID_DIRECTION			17
 #define _EAPI_STATUS_INVALID_BITMASK			18
 #define _EAPI_STATUS_RUNNING					19
 #define _EAPI_STATUS_UNSUPPORTED				20
 #define _EAPI_STATUS_NOT_FOUND					21
 #define _EAPI_STATUS_TIMEOUT					22
 #define _EAPI_STATUS_BUSY_COLLISION			23
 #define _EAPI_STATUS_READ_ERROR				24
 #define _EAPI_STATUS_WRITE_ERROR				25
 #define _EAPI_STATUS_MORE_DATA					26
 #define _EAPI_STATUS_ERROR						27


using namespace std;

char cOption;
char cOption_2;


void Help_Header(void)
{
    printf("\nEAPI_Test Manual:\n");
}

void Help_L(void)
{
    printf("\nInformation functions:\n");
    printf("EAPI_Test -<Option_1><Option_2> {<param_1> ... <param_n>}\n\n");
    printf("           -ls -> Call EApiBoardGetValue to get EAPI_ID_GET_EAPI_SPEC_VERSION\n");
    printf("                  No parameter required\n\n");
    printf("           -lu -> Call EApiBoardGetValue to get EAPI_ID_BOARD_BOOT_COUNTER_VAL\n");
    printf("                  No parameter required\n\n");
    printf("           -lg -> Call EApiBoardGetValue to get EAPI_ID_BOARD_RUNNING_TIME_METER\n");
    printf("                  No parameter required\n\n");
    printf("           -l9 -> Call EApiBoardGetValue to get EAPI_ID_BOARD_PNPID\n");
    printf("                  No parameter required\n\n");
    printf("           -lp -> Call EApiBoardGetValue to get EAPI_ID_BOARD_PLATFORM_REV_VAL\n");
    printf("                  No parameter required\n\n");
    printf("           -l7 -> Call EApiBoardGetValue to get EAPI_ID_BOARD_DRIVER_VERSION\n");
    printf("                  No parameter required\n\n");
    printf("           -ll -> Call EApiBoardGetValue to get EAPI_ID_BOARD_LIB_VERSION_VAL\n");
    printf("                  No parameter required\n\n");
    printf("           -lc -> Call EApiBoardGetValue to get EAPI_ID_HWMON_CPU_TEMP\n");
    printf("                  No parameter required\n\n");
    printf("           -ly -> Call EApiBoardGetValue to get EAPI_ID_HWMON_CHIPSET_TEMP\n");
    printf("                  No parameter required\n\n");
    printf("           -l8 -> Call EApiBoardGetValue to get EAPI_ID_HWMON_SYSTEM_TEMP\n");
    printf("                  No parameter required\n\n");
    printf("           -lo -> Call EApiBoardGetValue to get EAPI_ID_HWMON_VOLTAGE_VCORE\n");
    printf("                  No parameter required\n\n");
    printf("           -l2 -> Call EApiBoardGetValue to get EAPI_ID_HWMON_VOLTAGE_2V5\n");
    printf("                  No parameter required\n\n");
    printf("           -l3 -> Call EApiBoardGetValue to get EAPI_ID_HWMON_VOLTAGE_3V3\n");
    printf("                  No parameter required\n\n");
    printf("           -lw -> Call EApiBoardGetValue to get EAPI_ID_HWMON_VOLTAGE_VBAT\n");
    printf("                  No parameter required\n\n");
    printf("           -l5 -> Call EApiBoardGetValue to get EAPI_ID_HWMON_VOLTAGE_5V\n");
    printf("                  No parameter required\n\n");
    printf("           -lv -> Call EApiBoardGetValue to get EAPI_ID_HWMON_VOLTAGE_5VSB\n");
    printf("                  No parameter required\n\n");
    printf("           -l1 -> Call EApiBoardGetValue to get EAPI_ID_HWMON_VOLTAGE_12V\n");
    printf("                  No parameter required\n\n");
    printf("           -lf -> Call EApiBoardGetValue to get EAPI_ID_HWMON_FAN_CPU\n");
    printf("                  No parameter required\n\n");
    printf("           -la -> Call EApiBoardGetValue to get EAPI_ID_HWMON_FAN_SYSTEM\n");
    printf("                  No parameter required\n\n");

    printf("           -lz -> Call EApiBoardGetValue to get EAPI_ID_HWMON_RAM_TEMP\n");
    printf("                  No parameter required\n\n");
    printf("           -li -> Call EApiBoardGetValue to get EAPI_ID_SWITCH_STATUS\n");
    printf("                  No parameter required\n\n");

    printf("           -lm -> Call EApiBoardGetStringA to get EAPI_ID_BOARD_MANUFACTURER_STR\n");
    printf("                  No parameter required\n\n");
    printf("           -ln -> Call EApiBoardGetStringA to get EAPI_ID_BOARD_NAME_STR\n");
    printf("                  No parameter required\n\n");
    printf("           -lr -> Call EApiBoardGetStringA to get EAPI_ID_BOARD_REVISION_STR\n");
    printf("                  No parameter required\n\n");
    printf("           -le -> Call EApiBoardGetStringA to get EAPI_ID_BOARD_SERIAL_STR\n");
    printf("                  No parameter required\n\n");
    printf("           -lb -> Call EApiBoardGetStringA to get EAPI_ID_BOARD_BIOS_REVISION_STR\n");
    printf("                  No parameter required\n\n");
    printf("           -lh -> Call EApiBoardGetStringA to get EAPI_ID_BOARD_HW_REVISION_STR\n");
    printf("                  No parameter required\n\n");
    printf("           -lt -> Call EApiBoardGetStringA to get EAPI_ID_BOARD_PLATFORM_TYPE_STR\n");
    printf("                  No parameter required\n\n");
    printf("           -l? -> Print 'Information functions' help\n");
    printf("                  No parameter required\n");
    printf("\n           -------------------------------------------------------------------------\n");
}

void Help_V(void)
{
    printf("\nDisplay functions:\n");
    printf("EAPI_Test -<Option_1><Option_2> {<param_1> ... <param_n>}\n\n");
    printf("           -vg -> Call EApiVgaGetBacklightBrightness to get backlight brightness\n");
    printf("                  No parameter required\n\n");
    printf("           -vs -> Call EApiVgaSetBacklightBrightness to set backlight brightness\n");
    printf("                  <param_1> -> Backlight brightness percentage value (between 0 and EAPI_BACKLIGHT_SET_BRIGHTEST)\n\n");
    printf("           -vb -> Call EApiVgaGetBacklightEnable to get backlight status\n");
    printf("                  No parameter required\n\n");
    printf("           -ve -> Call EApiVgaSetBacklightEnable to set backlight status (enable or disable backlight)\n");
    printf("                  <param_1> -> 0 to disable and 1 to enable\n");
    printf("           -v? -> Print 'Display functions' help\n");
    printf("                  No parameter required\n");
    printf("\n           -------------------------------------------------------------------------\n");
}

void Help_S(void)
{
    printf("\nStorage area functions:\n");
    printf("EAPI_Test -<Option_1><Option_2> {<param_1> ... <param_n>}\n\n");
    printf("           -ss -> Call EApiStorageCap to get NVS capabilities\n");
    printf("                  No parameter required\n\n");
    printf("           -sr -> Call EApiStorageAreaRead to read data from the selected user data area\n");
    printf("                  <param_1> -> Number of bytes to read\n");
    printf("                  <param_2> -> Storage area start address offset in bytes\n\n");
    printf("           -sw -> Call EApiStorageAreaWrite to write data to the selected user data area.\n");
    printf("                  <param_1> -> Number of bytes to write\n");
    printf("                  <param_2> -> Storage area start address offset in bytes\n");
    printf("                  <param_3> ... <param_n> -> Bytes to write\n");
    printf("           -s? -> Print 'Storage area functions' help\n");
    printf("                  No parameter required\n");
    printf("\n           -------------------------------------------------------------------------\n");
}

void Help_W(void)
{
    printf("\nWatch dog functions:\n");
    printf("EAPI_Test -<Option_1><Option_2> {<param_1> ... <param_n>}\n\n");
    printf("           -wc -> Call EApiWDogGetCap to get the capabilities of the watchdog timer\n");
    printf("                  No parameter required\n\n");
    printf("           -ws -> Call EApiWDogStart to start the watchdog timer and set the parameters\n");
    printf("                  <param_1> -> Delay Timeout in msec\n");
    printf("                  <param_2> -> Event Timeout in msec\n");
    printf("                  <param_3> -> Reset Timeout in msec\n\n");
    printf("           -wt -> Call EApiWDogTrigger to trigger the watchdog timer\n");
    printf("                  No parameter required\n\n");
    printf("           -wd -> Call EApiWDogStop to get xxx\n");
    printf("                  No parameter required\n\n");
    printf("           -wr -> Call EApiWDog_SetConfigAndStart to start the watchdog timer and set the extended parameters\n");
    printf("                  <param_1> -> Delay Timeout in msec\n");
    printf("                  <param_2> -> Event Timeout in msec\n");
    printf("                  <param_3> -> Reset Timeout in msec\n");
    printf("                  <param_4> -> Event after reset timeout\n");
    printf("                               0 for signal\n");
    printf("                               1 for system reset\n");
    printf("                               2 for power button 1 sec\n");
    printf("                               3 for power button 4 sec\n");
    printf("                  <param_5> -> Trigger mode\n");
    printf("                               0 for software trigger\n");
    printf("                               1 for hardware trigger\n");
    printf("           -w? -> Print 'Watch dog functions' help\n");
    printf("                  No parameter required\n");
    printf("\n           -------------------------------------------------------------------------\n");
}

void Help_I(void)
{
    printf("\nI2C functions:\n");
    printf("EAPI_Test -<Option_1><Option_2> {<param_1> ... <param_n>}\n\n");
    printf("           -ic -> Call EApiI2CGetBusCap for I2C bus to get the capabilities\n");
    printf("                  <param_1> -> I2C bus:\n");
    printf("                               0 for EAPI_ID_I2C_EXTERNAL\n");
    printf("                               1 for EAPI_ID_I2C_LVDS_1\n");
    printf("                               2 for EAPI_ID_I2C_LVDS_2\n");
    printf("                               4 for EAPI_ID_I2C_INTERNAL\n");
    printf("           -ie -> Call EApiI2CWriteReadRaw for I2C bus for read and write operations\n");
    printf("                  <param_1> -> I2C bus:\n");
    printf("                               0 for EAPI_ID_I2C_EXTERNAL\n");
    printf("                               1 for EAPI_ID_I2C_LVDS_1\n");
    printf("                               2 for EAPI_ID_I2C_LVDS_2\n");
    printf("                               4 for EAPI_ID_I2C_INTERNAL\n");
    printf("                  <param_2> -> Device Address\n");
    printf("                  <param_3> -> Number of bytes to write\n");
    printf("                  <param_4> -> Number of bytes to read\n");
    printf("                  <param_5> ... <param_n> -> Byte to write\n\n");
    printf("           -ir -> Call EApiI2CReadTransfer for I2C bus to read byte from register\n");
    printf("                  <param_1> -> I2C bus:\n");
    printf("                               0 for EAPI_ID_I2C_EXTERNAL\n");
    printf("                               1 for EAPI_ID_I2C_LVDS_1\n");
    printf("                               2 for EAPI_ID_I2C_LVDS_2\n");
    printf("                               4 for EAPI_ID_I2C_INTERNAL\n");
    printf("                  <param_2> -> Device Address\n");
    printf("                  <param_3> -> Register\n\n");
    printf("           -iw -> Call EApiI2CWriteTransfer for I2C bus to write byte to register xxx\n");
    printf("                  <param_1> -> I2C bus:\n");
    printf("                               0 for EAPI_ID_I2C_EXTERNAL\n");
    printf("                               1 for EAPI_ID_I2C_LVDS_1\n");
    printf("                               2 for EAPI_ID_I2C_LVDS_2\n");
    printf("                               4 for EAPI_ID_I2C_INTERNAL\n");
    printf("                  <param_2> -> Device Address\n");
    printf("                  <param_3> -> Register\n");
    printf("                  <param_4> -> Register value to write\n\n");
    printf("           -ip -> Call EApiI2CProbeDevice for I2C bus to test device present\n");
    printf("                  <param_1> -> I2C bus:\n");
    printf("                               0 for EAPI_ID_I2C_EXTERNAL\n");
    printf("                               1 for EAPI_ID_I2C_LVDS_1\n");
    printf("                               2 for EAPI_ID_I2C_LVDS_2\n");
    printf("                               4 for EAPI_ID_I2C_INTERNAL\n");
    printf("                  <param_2> -> Device Address\n");
    printf("           -i? -> Print 'I2C functions' help\n");
    printf("                  No parameter required\n");
    printf("\n           -------------------------------------------------------------------------\n");
}

void Help_G(void)
{
    printf("\nGPIO functions:\n");
    printf("EAPI_Test -<Option_1><Option_2> {<param_1> ... <param_n>}\n\n");
    printf("           -gp -> Call EApiGPIOGetDirectionCaps to get the capabilities of the current GPIO implementation from the selected GPIO interface\n");
    printf("                  <param_1> -> Carrier boards where CPU module is connected\n");
    printf("                               0 for without carrier boars\n");
    printf("                               1 for M799\n");
    printf("                               2 for M901\n");
    printf("                               3 for 0A19\n");
    printf("                               4 for 0A42\n");
    printf("                               5 for 0857\n\n");
    printf("                  <param_2> -> ID (see 9.1.1 in COM_EAPI_R1_0.pdf\n");
    printf("           -gg -> Call EApiGPIOGetDirection to get the current configuration of the selected GPIO ports\n");
    printf("                  <param_1> -> Carrier boards where CPU module is connected\n");
    printf("                               0 for without carrier boars\n");
    printf("                               1 for M799\n");
    printf("                               2 for M901\n");
    printf("                               3 for 0A19\n");
    printf("                               4 for 0A42\n");
    printf("                               5 for 0857\n\n");
    printf("                  <param_2> -> ID (see 9.1.1 in COM_EAPI_R1_0.pdf\n");
    printf("                  <param_3> -> Bitmask (see 9.1 in COM_EAPI_R1_0.pdf\n");
    printf("           -gs -> Call EApiGPIOSetDirection to set the configuration for the selected GPIO ports\n");
    printf("                  <param_1> -> Carrier boards where CPU module is connected\n");
    printf("                               0 for without carrier boars\n");
    printf("                               1 for M799\n");
    printf("                               2 for M901\n");
    printf("                               3 for 0A19\n");
    printf("                               4 for 0A42\n");
    printf("                               5 for 0857\n");
    printf("                  <param_2> -> ID (see 9.1.1 in COM_EAPI_R1_0.pdf\n");
    printf("                  <param_3> -> Bitmask (see 9.1 in COM_EAPI_R1_0.pdf\n");
    printf("                  <param_4> -> Direction value to set\n\n");
    printf("           -gc -> Call EApiGPIOGetLevel to get level for the selected GPIO ports\n");
    printf("                  <param_1> -> Carrier boards where CPU module is connected\n");
    printf("                               0 for without carrier boars\n");
    printf("                               1 for M799\n");
    printf("                               2 for M901\n");
    printf("                               3 for 0A19\n");
    printf("                               4 for 0A42\n");
    printf("                               5 for 0857\n");
    printf("                  <param_2> -> ID (see 9.1.1 in COM_EAPI_R1_0.pdf\n");
    printf("                  <param_3> -> Bitmask (see 9.1 in COM_EAPI_R1_0.pdf\n");
    printf("           -gf -> Call EApiGPIOSetLevel to set level for the selected GPIO ports\n");
    printf("                  <param_1> -> Carrier boards where CPU module is connected\n");
    printf("                               0 for without carrier boars\n");
    printf("                               1 for M799\n");
    printf("                               2 for M901\n");
    printf("                               3 for 0A19\n");
    printf("                               4 for 0A42\n");
    printf("                               5 for 0857\n");
    printf("                  <param_2> -> ID (see 9.1.1 in COM_EAPI_R1_0.pdf\n");
    printf("                  <param_3> -> Bitmask (see 9.1 in COM_EAPI_R1_0.pdf\n");
    printf("                  <param_4> -> Level value to set\n\n");
    printf("           -gr -> Call EApiGPIOGetSerialCfg to get serial port configuration\n");
    printf("                  <param_1> -> Carrier boards where CPU module is connected\n");
    printf("                               0 for without carrier boars\n");
    printf("                               1 for M799\n");
    printf("                               2 for M901\n");
    printf("                               3 for 0A19\n");
    printf("                               4 for 0A42\n");
    printf("                               5 for 0857\n\n");
    printf("           -gq -> Call EApiGPIOSetSerialCfg to set serial port configuration\n");
    printf("                  <param_1> -> Carrier boards where CPU module is connected\n");
    printf("                               0 for without carrier boars\n");
    printf("                               1 for M799\n");
    printf("                               2 for M901\n");
    printf("                               3 for 0A19\n");
    printf("                               4 for 0A42\n");
    printf("                               5 for 0857\n");
    printf("                  <param_2> -> Carrier boards where CPU module is connected\n");
    printf("                               161 for RS232\n");
    printf("                               162 for RS422\n");
    printf("                               163 for RS485TX\n");
    printf("                               164 for RS485RX\n");
    printf("           -g? -> Print 'GPIO functions' help\n");
    printf("                  No parameter required\n");
    printf("\n           -------------------------------------------------------------------------\n");
}

void Help_F(void)
{
    printf("\nFAN functions:\n");
    printf("EAPI_Test -<Option_1><Option_2> {<param_1> ... <param_n>}\n\n");
    printf("           -fe -> Call EApiFanEnable to enable fan PWM\n");
    printf("                  <param_1> -> PWM cycle\n");
    printf("                  <param_2> -> PWM dutycycle\n\n");
    printf("           -fd -> Call EApiFanDisable to disable fan PWM\n");
    printf("                  No parameter required\n\n");
    printf("           -fg -> Call EApiFanPWMGetCycle to get fan PWM cycle\n");
    printf("                  No parameter required\n\n");
    printf("           -fs -> Call EApiFanPWMSetCycle to set fan PWM cycle\n");
    printf("                  <param_1> -> PWM cycle\n\n");
    printf("           -fu -> Call EApiFanPWMGetDutyCycle to get fan PWM dutycycle\n");
    printf("                  No parameter required\n\n");
    printf("           -fc -> Call EApiFanPWMSetDutyCycle to set fan PWM dutycycle\n");
    printf("                  <param_1> -> PWM cycle\n");
    printf("                  <param_2> -> PWM dutycycle\n");
    printf("           -f? -> Print 'FAN functions' help\n");
    printf("                  No parameter required\n");
    printf("\n           -------------------------------------------------------------------------\n");
}

void Help_R(void)
{
    printf("\nReset causes functions:\n");
    printf("EAPI_Test -<Option_1><Option_2> {<param_1> ... <param_n>}\n\n");
    printf("           -rg -> Call EApiGetResetCauses to get reset cause\n");
    printf("                  No parameter required\n\n");
    printf("           -rc -> Call EApiClearResetCauses to clear reset causes\n");
    printf("                  <param_1> -> reset causes to clear\n");
    printf("           -r? -> Print 'Reset causes functions' help\n");
    printf("                  No parameter required\n");
    printf("\n          -------------------------------------------------------------------------\n");
}

void Help_P(void)
{
    printf("\nSPI functions:\n");
    printf("EAPI_Test -<Option_1><Option_2> {<param_1> ... <param_n>}\n\n");
    printf("           -pc -> Call EApiSPIGetBusCap for SPI bus to get the capabilities\n");
    printf("                  No parameter required\n\n");
    printf("           -pe -> Call EApiSPIWriteReadRaw for SPI bus for read and write operations\n");
    printf("                  <param_1> -> SPI Configuration parameter (see EAPI User Guide)\n");
    printf("                  <param_2> -> SPI CS (see EAPI User Guide)\n");
    printf("                  <param_3> -> Number of bytes to write\n");
    printf("                  <param_4> -> Number of bytes to read\n");
    printf("                  <param_5> ... <param_n> -> Byte to write\n\n");
    printf("           -p? -> Print 'SPI functions' help\n");
    printf("                  No parameter required\n");
    printf("\n           -------------------------------------------------------------------------\n");
}

void Help_U(void)
{
    printf("\nUtility:\n");
    printf("EAPI_Test -<Option_1><Option_2> {<param_1> ... <param_n>}\n\n");
    printf("           -up -> Call EApiPowerRailCycle to start Power Railcycle\n");
    printf("                  No parameter required\n\n");
    printf("           -us -> Call EApiSetCarrier to set carrier board in use\n");
    printf("                  <param_1> -> Carrier boards where CPU module is connected\n");
    printf("                               0 for without carrier boars\n");
    printf("                               1 for M799\n");
    printf("                               2 for M901\n");
    printf("                               3 for 0A19\n");
    printf("                               4 for 0A42\n");
    printf("                               5 for 0857\n");
    printf("           -u? -> Print 'Utility' help\n");
    printf("                  No parameter required\n");
    printf("\n          -------------------------------------------------------------------------\n");
}

void ShowStatus(EApiStatus_t * Ret)
{
	switch(*Ret)
	{
		case EAPI_STATUS_NOT_INITIALIZED:
			 printf("(EAPI_STATUS_NOT_INITIALIZED)\n");
			 *Ret = _EAPI_STATUS_NOT_INITIALIZED;
			 break;
		case EAPI_STATUS_INITIALIZED:
			printf("(EAPI_STATUS_INITIALIZED)\n");
			 *Ret = _EAPI_STATUS_INITIALIZED;
			break;
		case EAPI_STATUS_ALLOC_ERROR:
			printf("(EAPI_STATUS_ALLOC_ERROR)\n");
			 *Ret = _EAPI_STATUS_ALLOC_ERROR;
			break;
		case EAPI_STATUS_DRIVER_TIMEOUT:
			printf("(EAPI_STATUS_DRIVER_TIMEOUT)\n");
			 *Ret = _EAPI_STATUS_DRIVER_TIMEOUT;
			break;
		case EAPI_STATUS_INVALID_PARAMETER:
			printf("(EAPI_STATUS_INVALID_PARAMETER)\n");
			 *Ret = _EAPI_STATUS_INVALID_PARAMETER;
			break;
		case EAPI_STATUS_INVALID_BLOCK_ALIGNMENT:
			printf("(EAPI_STATUS_INVALID_BLOCK_ALIGNMENT)\n");
			 *Ret = _EAPI_STATUS_INVALID_BLOCK_ALIGNMENT;
			break;
		case EAPI_STATUS_INVALID_BLOCK_LENGTH:
			printf("(EAPI_STATUS_INVALID_BLOCK_LENGTH)\n");
			 *Ret = _EAPI_STATUS_INVALID_BLOCK_LENGTH;
            break;
		case EAPI_STATUS_INVALID_DIRECTION:
			printf("(EAPI_STATUS_INVALID_DIRECTION)\n");
			 *Ret = _EAPI_STATUS_INVALID_DIRECTION;
			break;
		case EAPI_STATUS_INVALID_BITMASK:
			 printf("(EAPI_STATUS_INVALID_BITMASK)\n");
			 *Ret = _EAPI_STATUS_INVALID_BITMASK;
			break;
		case EAPI_STATUS_RUNNING:
            printf("(EAPI_STATUS_RUNNING)\n");
			 *Ret = _EAPI_STATUS_RUNNING;
			break;
		case EAPI_STATUS_UNSUPPORTED:
			printf("(EAPI_STATUS_UNSUPPORTED)\n");
			 *Ret = _EAPI_STATUS_UNSUPPORTED;
			break;
		case EAPI_STATUS_NOT_FOUND:
			printf("(EAPI_STATUS_NOT_FOUND)\n");
			 *Ret = _EAPI_STATUS_NOT_FOUND;
			break;
		case EAPI_STATUS_TIMEOUT:
			printf("(EAPI_STATUS_TIMEOUT)\n");
			 *Ret = _EAPI_STATUS_TIMEOUT;
			break;
		case EAPI_STATUS_BUSY_COLLISION:
			printf("(EAPI_STATUS_BUSY_COLLISION)\n");
			 *Ret = _EAPI_STATUS_BUSY_COLLISION;
			break;
		case EAPI_STATUS_READ_ERROR:
			printf("(EAPI_STATUS_READ_ERROR)\n");
			 *Ret = _EAPI_STATUS_READ_ERROR;
			break;
		case EAPI_STATUS_WRITE_ERROR:
			printf("(EAPI_STATUS_WRITE_ERROR)\n");
			 *Ret = _EAPI_STATUS_WRITE_ERROR;
			break;
		case EAPI_STATUS_MORE_DATA:
			printf("(EAPI_STATUS_MORE_DATA)\n");
			 *Ret = _EAPI_STATUS_MORE_DATA;
			break;
		case EAPI_STATUS_ERROR:
			printf("(EAPI_STATUS_ERROR)\n");
			 *Ret = _EAPI_STATUS_ERROR;
			break;
		case EAPI_STATUS_SUCCESS:
			break;
		default:
			printf("(EAPI_STATUS_ERROR Generic)\n");
			break;
	}
}

int elev_pot(int valore, int esp)
{
    int iRet = 1;
    for(int i = 0; i < esp; i++)
		iRet *= valore;
    return iRet;
}

int parser(int argc, char* argv[], unsigned char* command, uint32_t* param, unsigned char* num_param)
{
	//########## Formatting error check ##########
    if((argc < 2) || ((argv[1][0] != '/') && (argv[1][0] != '-')))
        cOption = 'h';
    else
    {
        cOption     = (char)tolower(argv[1][1]);
        cOption_2   = (char)tolower(argv[1][2]);
    }

	//########## Parameter scan ##########
    switch(cOption)
    {
        case 'l':
        switch(cOption_2)
        {
            case's': *command = GET_SPEC_VERSION;		        break;
            case'u': *command = GET_BOARD_BOOT_COUNTER;	        break;
            case'g': *command = GET_BOARD_RUNNING_TIME_METER;	break;
            case'9': *command = GET_BOARD_PNPID;	            break;
            case'p': *command = GET_BOARD_PLATFORM_REV;         break;
            case'7': *command = GET_BOARD_DRIVER_VERSION;       break;
            case'l': *command = GET_BOARD_LIB_VERSION;	        break;
            case'c': *command = GET_HWMON_CPU_TEMP;		        break;
            case'y': *command = GET_HWMON_CHIPSET_TEMP;	        break;
            case'8': *command = GET_HWMON_SYSTEM_TEMP;	        break;
            case'o': *command = GET_HWMON_VOLTAGE_VCORE;        break;
            case'2': *command = GET_HWMON_VOLTAGE_2V5;	        break;
            case'3': *command = GET_HWMON_VOLTAGE_3V3;	        break;
            case'w': *command = GET_HWMON_VOLTAGE_VBAT;	        break;
            case'5': *command = GET_HWMON_VOLTAGE_5V;	        break;
            case'v': *command = GET_HWMON_VOLTAGE_5VSB;     	break;
            case'1': *command = GET_HWMON_VOLTAGE_12V;	        break;
            case'f': *command = GET_HWMON_FAN_CPU;		        break;
            case'a': *command = GET_HWMON_FAN_SYSTEM;	        break;

            case'z': *command = GET_HWMON_RAM_TEMP;		        break;
            case'i': *command = GET_SWITCH_STATUS;		        break;

            case'm': *command = GET_BOARD_MANUFACTURER;         break;
            case'n': *command = GET_BOARD_NAME;			        break;
            case'r': *command = GET_BOARD_REVISION;		        break;
            case'e': *command = GET_BOARD_SERIAL;		        break;
            case'b': *command = GET_BOARD_BIOS_REVISION;        break;
            case'h': *command = GET_BOARD_HW_REVISION;	        break;
            case't': *command = GET_BOARD_PLATFORM_TYPE;        break;
			// --------------------------------------------------
            case'?': *command = NONE; Help_L();	                break;
            default: *command = PARAMETER_ERROR; Help_L();	    break;
	    }
        break;

        case 'v':
        switch(cOption_2)
        {
            case'g': *command = GET_LCD_BACKLIGHT;              break;
            case's': *command = SET_LCD_BACKLIGHT;              break;
            case'b': *command = GET_LCD_BCKL_ENA;               break;
            case'e': *command = SET_LCD_BCKL_ENA;               break;
			// --------------------------------------------------
            case'?': *command = NONE; Help_V();	                break;
            default: *command = PARAMETER_ERROR; Help_V();	    break;
        }
        break;

        case 's':
        switch(cOption_2)
        {
            case's': *command = NVS_CAP;		                break;
            case'r': *command = NVS_READ;		                break;
            case'w': *command = NVS_WRITE;		                break;
			// --------------------------------------------------
            case'?': *command = NONE; Help_S();	                break;
            default: *command = PARAMETER_ERROR; Help_S();	    break;
        }
        break;

        case 'w':
        switch(cOption_2)
        {
            case'c': *command = WDOG_CAP;		                break;
            case's': *command = WDOG_START;		                break;
            case't': *command = WDOG_TRIGGER;	                break;
            case'd': *command = WDOG_STOP;		                break;
            case'r': *command = WDOG_START_CUSTOM;              break;
			// --------------------------------------------------
            case'?': *command = NONE; Help_W();	                break;
            default: *command = PARAMETER_ERROR; Help_W();	    break;
        }
        break;

        case 'i':
        switch(cOption_2)
        {
            case'c': *command = I2C_CAP;			            break;
            case'e': *command = I2C_WRITE_READ_RAW;             break;
            case'r': *command = I2C_READ;			            break;
            case'w': *command = I2C_WRITE;			            break;
            case'p': *command = I2C_PROBE;			            break;
			// --------------------------------------------------
            case'?': *command = NONE; Help_I();	                break;
            default: *command = PARAMETER_ERROR; Help_I();	    break;
        }
        break;

        case 'g':
        switch(cOption_2)
        {
            case'p': *command = GPIO_GET_DIRECTION_CAP;             break;
            case'g': *command = GPIO_GET_DIRECTION;		            break;
            case's': *command = GPIO_SET_DIRECTION;		            break;
            case'c': *command = GPIO_GET_LEVEL;			            break;
            case'f': *command = GPIO_SET_LEVEL;			            break;
            case'r': *command = GPIO_GET_SERIAL_CFG;                break;
            case'q': *command = GPIO_SET_SERIAL_CFG;                break;
			// --------------------------------------------------
            case'?': *command = NONE; Help_G();	                    break;
            default: *command = PARAMETER_ERROR; Help_G();	        break;
        }
        break;

        case 'f':
        switch(cOption_2)
        {
            case'e': *command = FAN_ENABLE;		                    break;
            case'd': *command = FAN_DISABLE;	                    break;
            case'g': *command = FAN_GET_CYCLE;                      break;
            case's': *command = FAN_SET_CYCLE;                      break;
            case'u': *command = FAN_GET_DUTY;	                    break;
            case'c': *command = FAN_SET_DUTY;	                    break;
			// --------------------------------------------------
            case'?': *command = NONE; Help_F();	                    break;
            default: *command = PARAMETER_ERROR; Help_F();	        break;
        }
        break;

        case 'r':
        switch(cOption_2)
        {
            case'g': *command = GET_RESET_CAUSE;	                break;
            case'c': *command = CLEAR_RESET_CAUSE;	                break;
			// --------------------------------------------------
            case'?': *command = NONE; Help_R();	                    break;
            default: *command = PARAMETER_ERROR; Help_R();	        break;
        }
        break;

        case 'p':
        switch(cOption_2)
        {
            case'c': *command = SPI_CAP;			                break;
            case'e': *command = SPI_WRITE_READ_RAW;                 break;
			// --------------------------------------------------
            case'?': *command = NONE; Help_P();	                    break;
            default: *command = PARAMETER_ERROR; Help_P();	        break;
        }
        break;


        case 'u':
        switch(cOption_2)
        {
            case'p': *command = POWER_RAIL_CYCLE;	                break;
            case's': *command = SET_CARRIER;	                    break;
			// --------------------------------------------------
            case'?': *command = NONE; Help_U();	                    break;
            default: *command = PARAMETER_ERROR; Help_U();	        break;
        }
        break;

        case 'h':
        case '?':
			*command = HELP;
			Help_Header();
			Help_L();
			Help_V();
			Help_S();
			Help_W();
			Help_I();
			Help_G();
			Help_F();
			Help_R();
			Help_P();
			Help_U();
			return 0;
        break;

        default:
        *command = PARAMETER_ERROR;
        break;
    }

	//########## Fill Parameter array ##########
	*num_param = argc - 2;

	for(int a = 2; a < argc; a++)
	{
        //printf("00 - 0x%02X 0x%02X 0x%02X 0x%02X 0x%02X\n", argv[a][0], argv[a][1], argv[a][2], argv[a][3], argv[a][4]);
		unsigned char len = (unsigned char)strlen(argv[a]);

		param[a - 2] = 0;

		if((argv[a][0] == '0') && ((argv[a][1] == 'X') || (argv[a][1] == 'x')))
		{
            //printf("01\n");
			for(int b = 2; b < len; b++)
			{
                if(argv[a][b] == 0x0D)
                {
                    param[a - 2] = param[a - 2] >> 4;
                    return 0;
                }

                //printf("01\n");
				argv[a][b] = (char)tolower(argv[a][b]);
				if((argv[a][b] >= 0x61) && (argv[a][b] <= 0x66))
					param[a - 2] += (argv[a][b] - 87) * elev_pot(16, len - b - 1);
				else if((argv[a][b] >= 0x30) && (argv[a][b] <= 0x39))
					param[a - 2] += (argv[a][b] - 0x30) * elev_pot(16, len - b - 1);
				else
				{
                    //printf("01a\n");
					*num_param = 0;
					return 0;
				}
				//printf("param[a - 2] = 0x%02X\n", param[a - 2]);
			}
		}
		else
		{
           // printf("02\n");
			for(int b = 0; b < len; b++)
			{
                if(argv[a][b] == 0x0D)
                {
                    param[a - 2] = param[a - 2] / 10;
                    return 0;
                }

                //printf("03\n");
				if((argv[a][b] >= 0x30) && (argv[a][b] <= 0x39))
					param[a - 2] += (argv[a][b] - 0x30) * elev_pot(10, len - b - 1);
				else
				{
					*num_param = 0;
					return 0;
				}
			}
		}
	}

    return 0;
}


#ifdef CODE_for_LINUX
int main(int argc,char* argv[])
#endif

#ifdef CODE_for_WINDOWS
int _tmain(int argc, char* argv[])
#endif

#ifdef CODE_for_CE
int _tmain(int argc, char* argv[])
#endif
{
	char		StringValue[EAPI_MAX_LEN_STRING];
	uint32_t    StringLen;
	uint32_t	Value;

	uint8_t		*RBuffer;
	uint8_t	    Buffer[EAPI_MAX_LEN_STRING];
	uint32_t    Offset;
	uint32_t	BufferCnt;

	uint32_t	DelayTimeout;
	uint32_t	EventTimeout;
	uint32_t	ResetTimeout;
    uint8_t     mode_Event;
    uint8_t     mode_Trigger_Type;
    uint32_t    Event = EAPI_WTD_MODE_SYSTEM_RESET;
    uint8_t     Trigger_Type = EAPI_WTD_MODE_ENABLE_SW_TRIGGER;
	uint32_t    ReadCnt;
	uint32_t    WriteCnt;

	uint8_t		CS;
	uint32_t	config;

    uint32_t	Dev_Addr;

	uint32_t	Inputs;
    uint32_t	Outputs;

    uint8_t param_byte[128];
    uint32_t param[128];

    unsigned char command;
    unsigned char num_param;

	uint32_t	BlockLength;

	EApiStatus_t Ret = EAPI_STATUS_ERROR;

    parser(argc, argv, &command, param, &num_param);
    //printf("param = %d argc = %d num_param = %d\n", param[0], argc, num_param);

	//EApiEnableDebugLog(TRUE);

    if(command != PARAMETER_ERROR)
    {
		if((Ret = EApiLibInitialize()) != EAPI_STATUS_SUCCESS)
		{
			printf("EApiLibInitialize FAILED\n");
			return Ret;
		}
    }
    else
    {
        printf("PARAMETER_ERROR_1\n");
        return false;
    }

    switch(command)
    {
		case HELP:
			EApiLibUnInitialize();
			return true;
        break;

		case GET_SPEC_VERSION:
			if((Ret = EApiBoardGetValue(EAPI_ID_GET_EAPI_SPEC_VERSION, &Value)) == EAPI_STATUS_SUCCESS)
				printf("EAPI_ID_GET_EAPI_SPEC_VERSION -> v.%d.%d.%d\n",	((Value & 0xFF000000) >> 24), ((Value & 0x00FF0000) >> 16), (Value & 0x0000FFFF));
			else
			    printf("EAPI_ID_GET_EAPI_SPEC_VERSION -> FAILED\n");
			ShowStatus(&Ret);
			break;
        case GET_BOARD_BOOT_COUNTER:
            if((Ret = EApiBoardGetValue(EAPI_ID_BOARD_BOOT_COUNTER_VAL, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_BOARD_BOOT_COUNTER_VAL -> %d\n", Value);
            else
				printf("EAPI_ID_BOARD_BOOT_COUNTER_VAL -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_BOARD_RUNNING_TIME_METER:
            if((Ret = EApiBoardGetValue(EAPI_ID_BOARD_RUNNING_TIME_METER_VAL, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_BOARD_RUNNING_TIME_METER_VAL -> %d\n", Value);
            else
				printf("EAPI_ID_BOARD_RUNNING_TIME_METER_VAL -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_BOARD_PNPID:
            if((Ret = EApiBoardGetValue(EAPI_ID_BOARD_PNPID_VAL, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_BOARD_PNPID_VAL -> %d\n", Value);
            else
				printf("EAPI_ID_BOARD_PNPID_VAL -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_BOARD_PLATFORM_REV:
            if((Ret = EApiBoardGetValue(EAPI_ID_BOARD_PLATFORM_REV_VAL, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_BOARD_PLATFORM_REV_VAL -> v.%d.%d.%d\n",	((Value & 0xFF000000) >> 24), ((Value & 0x00FF0000) >> 16), (Value & 0x0000FFFF));
            else
			    printf("EAPI_ID_BOARD_PLATFORM_REV_VAL -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_BOARD_DRIVER_VERSION:
            if((Ret = EApiBoardGetValue(EAPI_ID_BOARD_DRIVER_VERSION_VAL, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_BOARD_DRIVER_VERSION_VAL -> %d\n", Value);
            else
				printf("EAPI_ID_BOARD_DRIVER_VERSION_VAL -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_BOARD_LIB_VERSION:
			if((Ret = EApiBoardGetValue(EAPI_ID_BOARD_LIB_VERSION_VAL, &Value)) == EAPI_STATUS_SUCCESS)
				printf("EAPI_ID_BOARD_LIB_VERSION_VAL -> v.%d.%d.%d\n",	((Value & 0xFF000000) >> 24), ((Value & 0x00FF0000) >> 16), (Value & 0x0000FFFF));
            else
				printf("EAPI_ID_BOARD_LIB_VERSION_VAL -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_HWMON_CPU_TEMP:
            if((Ret = EApiBoardGetValue(EAPI_ID_HWMON_CPU_TEMP, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_HWMON_CPU_TEMP -> %d\n", Value);
            else
				printf("EAPI_ID_HWMON_CPU_TEMP -> FAILED\n");
			ShowStatus(&Ret);
			return (Ret & 0xFFFFFFF);
            break;
        case GET_HWMON_CHIPSET_TEMP:
            if((Ret = EApiBoardGetValue(EAPI_ID_HWMON_CHIPSET_TEMP, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_HWMON_CHIPSET_TEMP -> %d\n", Value);
            else
				printf("EAPI_ID_HWMON_CHIPSET_TEMP -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_HWMON_SYSTEM_TEMP:
            if((Ret = EApiBoardGetValue(EAPI_ID_HWMON_SYSTEM_TEMP, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_HWMON_SYSTEM_TEMP -> %d\n", Value);
            else
				printf("EAPI_ID_HWMON_SYSTEM_TEMP -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_HWMON_VOLTAGE_VCORE:
            if((Ret = EApiBoardGetValue(EAPI_ID_HWMON_VOLTAGE_VCORE, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_HWMON_VOLTAGE_VCORE -> %d\n", Value);
            else
				printf("EAPI_ID_HWMON_VOLTAGE_VCORE -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_HWMON_VOLTAGE_2V5:
            if((Ret = EApiBoardGetValue(EAPI_ID_HWMON_VOLTAGE_2V5, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_HWMON_VOLTAGE_2V5 -> %d\n", Value);
            else
				printf("EAPI_ID_HWMON_VOLTAGE_2V5 -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_HWMON_VOLTAGE_3V3:
            if((Ret = EApiBoardGetValue(EAPI_ID_HWMON_VOLTAGE_3V3, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_HWMON_VOLTAGE_3V3 -> %d\n", Value);
            else
				printf("EAPI_ID_HWMON_VOLTAGE_3V3 -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_HWMON_VOLTAGE_VBAT:
            if((Ret = EApiBoardGetValue(EAPI_ID_HWMON_VOLTAGE_VBAT, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_HWMON_VOLTAGE_VBAT -> %d\n", Value);
            else
				printf("EAPI_ID_HWMON_VOLTAGE_VBAT -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_HWMON_VOLTAGE_5V:
            if((Ret = EApiBoardGetValue(EAPI_ID_HWMON_VOLTAGE_5V, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_HWMON_VOLTAGE_5V -> %d\n", Value);
            else
				printf("EAPI_ID_HWMON_VOLTAGE_5V -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_HWMON_VOLTAGE_5VSB:
            if((Ret = EApiBoardGetValue(EAPI_ID_HWMON_VOLTAGE_5VSB, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_HWMON_VOLTAGE_5VSB -> %d\n", Value);
            else
				printf("EAPI_ID_HWMON_VOLTAGE_5VSB -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_HWMON_VOLTAGE_12V:
            if((Ret = EApiBoardGetValue(EAPI_ID_HWMON_VOLTAGE_12V, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_HWMON_VOLTAGE_12V -> %d\n", Value);
            else
				printf("EAPI_ID_HWMON_VOLTAGE_12V -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_HWMON_FAN_SYSTEM:
            if((Ret = EApiBoardGetValue(EAPI_ID_HWMON_FAN_SYSTEM, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_HWMON_FAN_SYSTEM -> %d\n", Value);
            else
				printf("EAPI_ID_HWMON_FAN_SYSTEM -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_HWMON_FAN_CPU:
            if((Ret = EApiBoardGetValue(EAPI_ID_HWMON_FAN_CPU, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_HWMON_FAN_CPU -> %d\n", Value);
            else
				printf("EAPI_ID_HWMON_FAN_CPU -> FAILED\n");
			ShowStatus(&Ret);;
            break;
        case GET_HWMON_RAM_TEMP:
            if((Ret = EApiBoardGetValue(EAPI_ID_HWMON_RAM_TEMP, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_HWMON_RAM_TEMP -> %d\n", Value);
            else
				printf("EAPI_ID_HWMON_RAM_TEMP -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_SWITCH_STATUS:
            if((Ret = EApiBoardGetValue(EAPI_ID_GET_SWITCH_STATUS, &Value)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_GET_SWITCH_STATUS -> %d\n", Value);
            else
				printf("EAPI_ID_GET_SWITCH_STATUS -> FAILED\n");
			ShowStatus(&Ret);
            break;
// --------------------------------------------------------------------------------------------------
        case GET_BOARD_MANUFACTURER:
			StringLen = sizeof(StringValue);
            if((Ret = EApiBoardGetStringA( EAPI_ID_BOARD_MANUFACTURER_STR, StringValue, &StringLen)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_BOARD_MANUFACTURER_STR -> %s\n", StringValue);
            else
				printf("EAPI_ID_BOARD_MANUFACTURER_STR -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_BOARD_NAME:
			StringLen = sizeof(StringValue);
            if((Ret = EApiBoardGetStringA( EAPI_ID_BOARD_NAME_STR, StringValue, &StringLen)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_BOARD_NAME_STR -> %s\n", StringValue);
            else
				printf("EAPI_ID_BOARD_NAME_STR -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_BOARD_REVISION:
			StringLen = sizeof(StringValue);
            if((Ret = EApiBoardGetStringA( EAPI_ID_BOARD_REVISION_STR, StringValue, &StringLen)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_BOARD_REVISION_STR -> %s\n", StringValue);
            else
				printf("EAPI_ID_BOARD_REVISION_STR -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_BOARD_SERIAL:
			StringLen = sizeof(StringValue);
            if((Ret = EApiBoardGetStringA( EAPI_ID_BOARD_SERIAL_STR, StringValue, &StringLen)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_BOARD_SERIAL_STR -> %s\n", StringValue);
            else
				printf("EAPI_ID_BOARD_SERIAL_STR -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_BOARD_BIOS_REVISION:
			StringLen = sizeof(StringValue);
            if((Ret = EApiBoardGetStringA( EAPI_ID_BOARD_BIOS_REVISION_STR, StringValue, &StringLen)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_BOARD_BIOS_REVISION_STR -> %s\n", StringValue);
            else
				printf("EAPI_ID_BOARD_BIOS_REVISION_STR -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_BOARD_HW_REVISION:
			StringLen = sizeof(StringValue);
            if((Ret = EApiBoardGetStringA( EAPI_ID_BOARD_HW_REVISION_STR, StringValue, &StringLen)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_BOARD_HW_REVISION_STR -> %s\n", StringValue);
            else
				printf("EAPI_ID_BOARD_HW_REVISION_STR -> FAILED\n");
			ShowStatus(&Ret);
            break;
        case GET_BOARD_PLATFORM_TYPE:
			StringLen = sizeof(StringValue);
            if((Ret = EApiBoardGetStringA( EAPI_ID_BOARD_PLATFORM_TYPE_STR, StringValue, &StringLen)) == EAPI_STATUS_SUCCESS)
                printf("EAPI_ID_BOARD_PLATFORM_TYPE_STR -> %s\n", StringValue);
            else
				printf("EAPI_ID_BOARD_PLATFORM_TYPE_STR -> FAILED\n");
			ShowStatus(&Ret);
            break;
// --------------------------------------------------------------------------------------------------
        case GET_LCD_BACKLIGHT:
            if(num_param == 0)
            {
                if((Ret = EApiVgaGetBacklightBrightness(EAPI_ID_BACKLIGHT_1, &Value)) == EAPI_STATUS_SUCCESS)
                    printf("EApiVgaGetBacklightBrightness = %d\n", Value);
				else
					printf("EApiVgaGetBacklightBrightness -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case SET_LCD_BACKLIGHT:
            Value =	param[0];

            if(num_param == 1)
            {
                if((Ret = EApiVgaSetBacklightBrightness(EAPI_ID_BACKLIGHT_1, Value)) == EAPI_STATUS_SUCCESS)
                    printf("EApiVgaSetBacklightBrightness -> OK\n");
				else
					printf("EApiVgaSetBacklightBrightness -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case GET_LCD_BCKL_ENA:
            if(num_param == 0)
            {
                if((Ret = EApiVgaGetBacklightEnable(EAPI_ID_BACKLIGHT_1, &Value)) == EAPI_STATUS_SUCCESS)
                    printf("EApiVgaGetBacklightBrightness = %d\n", Value);
				else
					printf("EApiVgaGetBacklightEnable -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case SET_LCD_BCKL_ENA:
            if(param[0] == 0)
                Value = EAPI_BACKLIGHT_SET_OFF;
            else
                Value = EAPI_BACKLIGHT_SET_ON;

            if(num_param == 1)
            {
                if((Ret = EApiVgaSetBacklightEnable(EAPI_ID_BACKLIGHT_1, Value)) == EAPI_STATUS_SUCCESS)
                    printf("EApiVgaSetBacklightEnable -> OK\n");
				else
					printf("EApiVgaSetBacklightEnable -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
// --------------------------------------------------------------------------------------------------
        case NVS_CAP:
            if(num_param == 0)
            {
                if((Ret = EApiStorageCap(EAPI_ID_STORAGE_STD, &Value, &BlockLength)) == EAPI_STATUS_SUCCESS)
                    printf("EApiStorageCap = %d\n", Value);
				else
					printf("EApiStorageCap -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case NVS_READ:
			RBuffer = new uint8_t[param[0]];
            BufferCnt = param[0];
            Offset = param[1];

            if(num_param == 2)
            {
                if((Ret = EApiStorageAreaRead(EAPI_ID_STORAGE_STD, Offset, RBuffer, BufferCnt, BufferCnt)) == EAPI_STATUS_SUCCESS)
                    for(unsigned long e = 0; e < BufferCnt; e++)
                        printf("EApiStorageAreaRead -> ReadByte[%lu] = 0x%02X\n", param[1] + e, RBuffer[e]);
				else
					printf("EApiStorageAreaRead -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
			delete []RBuffer;
            break;
         case NVS_WRITE:
            BufferCnt = param[0];
            Offset = param[1];

            for(unsigned short a = 0; a < BufferCnt; a++)
                param_byte[a] = (unsigned char)param[a + 2];

            if(num_param == (2 + BufferCnt))
            {
                if((Ret = EApiStorageAreaWrite(EAPI_ID_STORAGE_STD, Offset, param_byte, BufferCnt)) == EAPI_STATUS_SUCCESS)
                    printf("EApiStorageAreaWrite -> OK\n");
				else
					printf("EApiStorageAreaWrite -> FAILED\n");
				return (Ret & 0xFFFFFFF);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
// --------------------------------------------------------------------------------------------------
        case WDOG_CAP:
			if(num_param == 0)
			{
                if((Ret = EApiWDogGetCap(&DelayTimeout, &EventTimeout, &ResetTimeout)) == EAPI_STATUS_SUCCESS)
                {
                    printf("EApiWDogGetCap.MaxDelay = %d\n", DelayTimeout);
                    printf("EApiWDogGetCap.MaxEventTimeout = %d\n", EventTimeout);
                    printf("EApiWDogGetCap.MaxResetTimeout = %d\n", ResetTimeout);
                }
				else
					printf("EApiWDogGetCap -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case WDOG_START:
            if(num_param == 3)
            {
                DelayTimeout = param[0];
                EventTimeout = param[1];
                ResetTimeout = param[2];
                if((Ret = EApiWDogStart(DelayTimeout, EventTimeout, ResetTimeout)) == EAPI_STATUS_SUCCESS)
					printf("EApiWDogStart -> OK\n");
				else
					printf("EApiWDogStart -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case WDOG_TRIGGER:
            if(num_param == 0)
            {
                if((Ret = EApiWDogTrigger()) == EAPI_STATUS_SUCCESS)
					printf("EApiWDogTrigger -> OK\n");
				else
					printf("EApiWDogTrigger -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case WDOG_STOP:
            if(num_param == 0)
            {
                if((Ret = EApiWDogStop()) == EAPI_STATUS_SUCCESS)
					printf("EApiWDogStop -> OK\n");
				else
					printf("EApiWDogStop -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case WDOG_START_CUSTOM:
            if(num_param == 5)
            {
                DelayTimeout =	param[0];
                EventTimeout =	param[1];
                ResetTimeout =	param[2];
                mode_Event = (uint8_t)param[3];
                mode_Trigger_Type =	(uint8_t)param[4];

                switch(mode_Event)
                {
                    case 0:
                        Event = EAPI_WTD_MODE_SIGNAL;
                        break;
                    case 1:
                        Event = EAPI_WTD_MODE_SYSTEM_RESET;
                        break;
                    case 2:
                        Event = EAPI_WTD_MODE_PWRBTN_1SEC;
                        break;
                    case 3:
                        Event = EAPI_WTD_MODE_PWRBTN_4SEC;
                        break;
                    default:
                        printf("Parameter error");
                        break;
                }

                switch(mode_Trigger_Type)
                {
                    case 0:
                        Trigger_Type = EAPI_WTD_MODE_ENABLE_SW_TRIGGER;
                        break;
                    case 1:
                        Trigger_Type = EAPI_WTD_MODE_ENABLE_HW_TRIGGER;
                        break;
                    default:
                        printf("Parameter error");
                        break;
                }

                if((Ret = EApiWDog_SetConfigAndStart(DelayTimeout,
                                              EventTimeout,
                                              ResetTimeout,
                                              Event,
                                              EAPI_WTD_MODE_IN_MSEC,
                                              EAPI_WTD_MODE_IN_MSEC,
                                              Trigger_Type)) == EAPI_STATUS_SUCCESS)
					printf("EApiWDog_SetConfigAndStart -> OK\n");
				else
					printf("EApiWDog_SetConfigAndStart -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
// --------------------------------------------------------------------------------------------------
        case I2C_CAP:
            if(num_param == 1)
            {
                if((Ret = EApiI2CGetBusCap(param[0], &Value)) == EAPI_STATUS_SUCCESS)
                    printf("EApiI2CGetBusCap -> 0x%02X\n", Value);
				else
					printf("EApiI2CGetBusCap -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case I2C_WRITE_READ_RAW:

            Dev_Addr = (uint8_t)param[1];
            WriteCnt = (uint8_t)param[2];
            ReadCnt  = (uint8_t)param[3];

            for(unsigned short a = 0; a < WriteCnt; a++)
                param_byte[a] = (unsigned char)param[a + 4];

            if(num_param == (4 + WriteCnt))
            {
                if((Ret = EApiI2CWriteReadRaw(param[0], Dev_Addr, param_byte, WriteCnt, Buffer, sizeof(Buffer), ReadCnt)) == EAPI_STATUS_SUCCESS)
                    if(ReadCnt != 0)
                    {
                        for(uint32_t a = 0; a < ReadCnt; a++)
                        { printf("EApiI2CWriteReadRaw -> ReadByte[%d] = 0x%02X\n",a, Buffer[a]); }
                    }
                    else
                        printf("EApiI2CWriteReadRaw -> OK\n");
				else
					printf("EApiI2CWriteReadRaw -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case I2C_READ:
            Dev_Addr = (uint8_t)param[1];
            Offset	 = (uint8_t)param[2];

            if(num_param == 3)
            {
                if((Ret = EApiI2CReadTransfer(param[0], Dev_Addr, Offset, Buffer, sizeof(Buffer), 1)) == EAPI_STATUS_SUCCESS)
                    printf("EApiI2CReadTransfer -> ReadByte = 0x%02X\n", Buffer[0]);
				else
					printf("EApiI2CReadTransfer -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case I2C_WRITE:
            Dev_Addr = (uint8_t)param[1];
            Offset   = (uint8_t)param[2];
            param_byte[0] = (uint8_t)param[3];

            if(num_param == 4)
            {
                 if((Ret = EApiI2CWriteTransfer(param[0], Dev_Addr, Offset, param_byte, 1)) == EAPI_STATUS_SUCCESS)
                    printf("EApiI2CWriteTransfer -> OK\n");
				else
					printf("EApiI2CWriteTransfer -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case I2C_PROBE:
            Dev_Addr = (uint8_t)param[1];

			if(num_param == 2)
            {
                if((Ret = EApiI2CProbeDevice(param[0], Dev_Addr)) == EAPI_STATUS_SUCCESS)
                    printf("EApiI2CProbeDevice -> OK\n");
				else
					printf("EApiI2CProbeDevice -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;

// --------------------------------------------------------------------------------------------------
        case GPIO_GET_DIRECTION_CAP:
            if(num_param == 2)
            {
                EApiSetCarrier((uint8_t)param[0]);

                if((Ret = EApiGPIOGetDirectionCaps(param[1], &Inputs, &Outputs)) == EAPI_STATUS_SUCCESS)
                {
                    printf("EApiGPIOGetDirectionCaps Inputs = 0x%08X\n", Inputs);
                    printf("EApiGPIOGetDirectionCaps Outputs = 0x%08X\n", Outputs);
				}
				else
					printf("EApiGPIOGetDirectionCaps -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case GPIO_GET_DIRECTION:
            if(num_param == 3)
            {
                EApiSetCarrier((uint8_t)param[0]);

                if((Ret = EApiGPIOGetDirection(param[1], param[2], &Value)) == EAPI_STATUS_SUCCESS)
                    printf("EApiGPIOGetDirection Directions = 0x%08X\n", Value);
				else
					printf("EApiGPIOGetDirection -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case GPIO_SET_DIRECTION:
            if(num_param == 4)
            {
                EApiSetCarrier((uint8_t)param[0]);

                if((Ret = EApiGPIOSetDirection(param[1], param[2], param[3])) == EAPI_STATUS_SUCCESS)
                    printf("EApiGPIOSetDirection Directions = 0x%08X\n", param[3]);
				else
					printf("EApiGPIOSetDirection -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case GPIO_GET_LEVEL:
            if(num_param == 3)
            {
                EApiSetCarrier((uint8_t)param[0]);

                if((Ret = EApiGPIOGetLevel(param[1], param[2], &Value)) == EAPI_STATUS_SUCCESS)
                    printf("EApiGPIOGetLevel Level = 0x%08X\n", Value);
				else
					printf("EApiGPIOGetLevel -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case GPIO_SET_LEVEL:
            if(num_param == 4)
            {
                EApiSetCarrier((uint8_t)param[0]);

                if((Ret = EApiGPIOSetLevel(param[1], param[2], param[3])) == EAPI_STATUS_SUCCESS)
                    printf("EApiGPIOSetLevel -> OK\n");
				else
					printf("EApiGPIOGetLevel -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case GPIO_GET_SERIAL_CFG:
            if(num_param == 1)
            {
                EApiSetCarrier((uint8_t)param[0]);

                if((Ret = EApiGPIOGetSerialCfg(Buffer)) == EAPI_STATUS_SUCCESS)
                    printf("EAPIGPIOGetSerialCfg = 0x%02X\n", Buffer[0]);
				else
					printf("EAPIGPIOGetSerialCfg -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case GPIO_SET_SERIAL_CFG:
            if(num_param == 2)
            {
                EApiSetCarrier((uint8_t)param[0]);

                if((Ret = EApiGPIOSetSerialCfg((uint8_t)param[1])) == EAPI_STATUS_SUCCESS)
                    printf("EApiGPIOSetSerialCfg -> OK\n");
				else
					printf("EApiGPIOSetSerialCfg -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
// --------------------------------------------------------------------------------------------------
       case FAN_ENABLE:
            if(num_param == 2)
            {
                uint16_t freq = (uint16_t)param[0];
                if((Ret = EApiFanEnable(/*FAN_FREQUENCY_5MHZ,*/ freq, (uint8_t)param[1])) == EAPI_STATUS_SUCCESS)
                    printf("EApiFanEnable -> OK\n");
				else
					printf("EApiFanEnable -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case FAN_DISABLE:
            if(num_param == 0)
            {
                if((Ret = EApiFanDisable()) == EAPI_STATUS_SUCCESS)
                    printf("EApiFanDisable -> OK\n");
				else
					printf("EApiFanDisable -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case FAN_GET_CYCLE:
            if(num_param == 0)
            {
                if((Ret = EApiFanPWMGetCycle(&Value)) == EAPI_STATUS_SUCCESS)
                    printf("EApiFanPWMGetCycle = 0x%02X\n", Value);
				else
					printf("EApiFanPWMGetCycle -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case FAN_SET_CYCLE:
            if(num_param == 1)
            {
                uint16_t freq = (uint16_t)param[0];
                if((Ret = EApiFanPWMSetCycle(freq)) == EAPI_STATUS_SUCCESS)
                    printf("EApiFanPWMSetCycle -> OK\n");
				else
					printf("EApiFanPWMSetCycle -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
         case FAN_GET_DUTY:
            if(num_param == 0)
            {
                uint8_t Val;
                if((Ret = EApiFanPWMGetDutyCycle(&Val)) == EAPI_STATUS_SUCCESS)
                    printf("EApiFanPWMGetDutyCycle = 0x%02X\n", Val);
				else
					printf("EApiFanPWMGetDutyCycle -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case FAN_SET_DUTY:
            if(num_param == 2)
            {
                uint16_t freq = (uint16_t)param[0];
                if((Ret = EApiFanPWMSetDutyCycle(freq, (uint8_t)param[1])) == EAPI_STATUS_SUCCESS)
                    printf("EApiFanPWMSetDutyCycle -> OK\n");
				else
					printf("EApiFanPWMSetDutyCycle -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
// --------------------------------------------------------------------------------------------------
        case GET_RESET_CAUSE:
            if(num_param == 0)
            {
                uint32_t ResetCauses;
                if((Ret = EApiGetResetCauses(&ResetCauses)) == EAPI_STATUS_SUCCESS)
                {
                    printf("EApiGetResetCauses = 0x%08X\n", ResetCauses);
                    if(ResetCauses & RESET_CAUSE_RESET)
                        printf("RESET_CAUSE_RESET\n");
                    if(ResetCauses & RESET_CAUSE_WDT)
                        printf("RESET_CAUSE_WDT\n");
                    if(ResetCauses & RESET_CAUSE_PWFAIL)
                        printf("RESET_CAUSE_PWFAIL\n");
                    if(ResetCauses & RESET_CAUSE_SWRESET)
                        printf("RESET_CAUSE_SWRESET\n");
                }
				else
					printf("EApiGetResetCauses -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case CLEAR_RESET_CAUSE:
            if(num_param == 1)
            {
                printf("Requested to clear:\n");
                if(param[0] & RESET_CAUSE_RESET)
                    printf("RESET_CAUSE_RESET\n");
                if(param[0] & RESET_CAUSE_WDT)
                    printf("RESET_CAUSE_WDT\n");
                if(param[0] & RESET_CAUSE_PWFAIL)
                    printf("RESET_CAUSE_PWFAIL\n");
                if(param[0] & RESET_CAUSE_SWRESET)
                    printf("RESET_CAUSE_SWRESET\n");

                if((Ret = EApiClearResetCauses(param[0])) == EAPI_STATUS_SUCCESS)
                    printf("EApiClearResetCauses -> OK\n");
				else
					printf("EApiClearResetCauses -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;

// --------------------------------------------------------------------------------------------------
        case SPI_CAP:
            if(num_param == 0)
            {
                if((Ret = EApiSPIGetBusCap(&Value)) == EAPI_STATUS_SUCCESS)
                {
                    printf("EApiSPIGetBusCap -> 0x%02X\n", Value);
                    return true;
                }
            }
            else
            {
                printf("Parameter error");
                return false;
            }

            printf("EApiSPIGetBusCap -> FAILED");
            return true;
            break;
        case SPI_WRITE_READ_RAW:
            config  = (uint16_t)param[0];
            CS = (uint8_t)param[1];
            WriteCnt = (uint8_t)param[2];
            ReadCnt  = (uint8_t)param[3];

            for(unsigned short a = 0; a < WriteCnt; a++)
                param_byte[a] = (unsigned char)param[a + 4];

            if(num_param == (4 + WriteCnt))
            {
                if((Ret = EApiSPIWriteReadRaw(config, CS, param_byte, WriteCnt, Buffer, ReadCnt)) == EAPI_STATUS_SUCCESS)
                {
                    if(ReadCnt != 0)
                    {
                        printf("EApiSPIWriteReadRaw -> ReadByte ->");
                        for(unsigned short a = 0; a < ReadCnt; a++)
                            printf(" 0x%02X", Buffer[a]);
                        printf("\n");
                    }
                    else
                        printf("EApiSPIWriteReadRaw -> OK\n");
                    return true;
                }
            }
            else
            {
                printf("Parameter error");
                return false;
            }

            printf("EApiSPIWriteReadRaw -> FAILED\n");
            ShowStatus(&Ret);
            break;
// --------------------------------------------------------------------------------------------------
        case POWER_RAIL_CYCLE:
            if(num_param == 0)
            {
                if((Ret = EApiPowerRailCycle()) == EAPI_STATUS_SUCCESS)
					printf("EApiPowerRailCycle -> OK\n");
				else
					printf("EApiPowerRailCycle -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
        case SET_CARRIER:
            if(num_param == 1)
            {
                if((Ret = EApiSetCarrier(param[0])) == EAPI_STATUS_SUCCESS)
                    printf("EApiSetCarrier -> OK\n");
				else
					printf("EApiSetCarrier -> FAILED\n");
				ShowStatus(&Ret);
            }
            else
            {
				printf("PARAMETER_ERROR\n");
            }
            break;
	}

    EApiLibUnInitialize();
    printf("\n");
    return Ret;
}
